@@ -8,6 +8,7 @@
 
 #pragma once
 
+#include <QFileSystemWatcher>
 #include <QImage>
 #include <QItemSelection>
 #include <QPointer>
@@ -355,6 +356,8 @@ private:
     Plasma::Applet *m_applet = nullptr;
     bool m_complete;
     QPoint m_menuPosition;
+    QFileSystemWatcher *watcher;
+    void addDirectoriesRecursively(const QString &resolvedNewUrl, QFileSystemWatcher *watcher);
 
     /**
      * This property is used to save the current activity when FolderModel is initialized.
