@@ -11,12 +11,9 @@
 #include <QString>
 #include <QStringList>
 #include <QWidget>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
 #include <QtGui/private/qtx11extras_p.h>
-#endif
 
+QT_WARNING_DISABLE_CLANG("-Wkeyword-macro")
 #define explicit explicit_is_keyword_in_cpp
 #include <xcb/xcb.h>
 #include <xcb/xkb.h>
@@ -60,11 +57,7 @@ protected:
     virtual bool processOtherEvents(xcb_generic_event_t *e);
     virtual bool processXkbEvents(xcb_generic_event_t *e);
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override;
-#else
     bool nativeEventFilter(const QByteArray &eventType, void *message, qintptr *result) override;
-#endif
 
 private:
     int registerForXkbEvents(Display *display);
@@ -215,7 +208,7 @@ struct LayoutSet {
     {
         QString str(currentLayout.toString());
         str += QLatin1String(": ");
-        for (const auto &layoutUnit : qAsConst(layouts)) {
+        for (const auto &layoutUnit : std::as_const(layouts)) {
             str += layoutUnit.toString() + QLatin1Char(' ');
         }
         return str;
