@@ -1,4 +1,4 @@
-/*
+﻿/*
     SPDX-FileCopyrightText: 2018 Roman Gilg <subdiff@gmail.com>
     SPDX-FileCopyrightText: 2021 Aleix Pol Gonzalez <aleixpol@kde.org>
 
@@ -9,6 +9,7 @@
 
 #include "InputDevice_interface.h"
 
+#include <QMatrix4x4>
 #include <QObject>
 #include <QString>
 
@@ -24,11 +25,13 @@ class InputDevice : public QObject
     Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled NOTIFY enabledChanged)
     Q_PROPERTY(bool supportsLeftHanded READ supportsLeftHanded CONSTANT)
     Q_PROPERTY(bool leftHanded READ isLeftHanded WRITE setLeftHanded NOTIFY leftHandedChanged)
+    Q_PROPERTY(bool supportsCalibrationMatrix READ supportsCalibrationMatrix CONSTANT)
 
     Q_PROPERTY(bool supportsOrientation READ supportsOrientation CONSTANT)
     Q_PROPERTY(int orientation READ orientation WRITE setOrientation NOTIFY orientationChanged)
     Q_PROPERTY(QString outputName READ outputName WRITE setOutputName NOTIFY outputNameChanged)
     Q_PROPERTY(QRectF outputArea READ outputArea WRITE setOutputArea NOTIFY outputAreaChanged)
+    Q_PROPERTY(bool mapToWorkspace READ isMapToWorkspace WRITE setMapToWorkspace NOTIFY mapToWorkspaceChanged)
 
 public:
     InputDevice(const QString &dbusName, QObject *parent);
@@ -84,13 +87,36 @@ public:
     }
     void setOutputArea(const QRectF &outputArea);
 
+    bool supportsCalibrationMatrix() const
+    {
+        return m_supportsCalibrationMatrix.value();
+    }
+
     bool isEnabled() const
     {
         return m_enabled.value();
     }
 
+    QMatrix4x4 defaultCalibrationMatrix() const
+    {
+        return m_iface->property("defaultCalibrationMatrix").value<QMatrix4x4>();
+    }
+
+    void setCalibrationMatrix(const QMatrix4x4 &matrix) const
+    {
+        // TODO: why does this not with our existing interface...?
+        QDBusInterface iface(QStringLiteral("org.kde.KWin"), m_iface->path());
+        iface.setProperty("calibrationMatrix", matrix);
+    }
+
     void setEnabled(bool enabled);
 
+    bool isMapToWorkspace() const
+    {
+        return m_mapToWorkspace.value();
+    }
+    void setMapToWorkspace(bool mapToWorkspace);
+
 Q_SIGNALS:
     void needsSaveChanged();
 
@@ -99,6 +125,7 @@ Q_SIGNALS:
     void outputNameChanged();
     void outputAreaChanged();
     void enabledChanged();
+    void mapToWorkspaceChanged();
 
 private:
     template<typename T>
@@ -215,5 +242,11 @@ private:
                                              &OrgKdeKWinInputDeviceInterface::supportsOutputArea,
                                              &InputDevice::outputAreaChanged);
 
+    Prop<bool> m_mapToWorkspace =
+        Prop<bool>(this, "mapToWorkspace", &OrgKdeKWinInputDeviceInterface::defaultMapToWorkspace, nullptr, &InputDevice::mapToWorkspaceChanged);
+
+    Prop<bool> m_supportsCalibrationMatrix =
+        Prop<bool>(this, "supportsCalibrationMatrix", nullptr, &OrgKdeKWinInputDeviceInterface::supportsCalibrationMatrix, nullptr);
+
     std::unique_ptr<OrgKdeKWinInputDeviceInterface> m_iface;
 };
