@@ -5,6 +5,7 @@
 */
 
 #include "kcmtablet.h"
+#include "calibrationtool.h"
 #include "inputdevice.h"
 #include "tabletevents.h"
 
@@ -12,6 +13,7 @@
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <QGuiApplication>
+#include <QMatrix4x4>
 #include <QScreen>
 #include <QStandardItemModel>
 
@@ -29,7 +31,7 @@ public:
             appendRow(item);
         };
 
-        addOrientation(i18n("Primary (default)"), Qt::PrimaryOrientation);
+        addOrientation(i18n("Default"), Qt::PrimaryOrientation);
         addOrientation(i18n("Portrait"), Qt::PortraitOrientation);
         addOrientation(i18n("Landscape"), Qt::LandscapeOrientation);
         addOrientation(i18n("Inverted Portrait"), Qt::InvertedPortraitOrientation);
@@ -83,16 +85,22 @@ public:
         clear();
 
         auto screens = qGuiApp->screens();
-        auto it = new QStandardItem(i18n("Follow the active screen"));
+        auto it = new QStandardItem(i18n("Follow the Current Screen"));
         it->setData(screens[0]->physicalSize(), Qt::UserRole + 1); // we use the first display to give an idea
         it->setData(screens[0]->size(), Qt::UserRole + 2);
         appendRow(it);
 
+        it = new QStandardItem(i18n("All Screens"));
+        it->setData(screens[0]->virtualSize(), Qt::UserRole + 1);
+        it->setData(screens[0]->virtualSize(), Qt::UserRole + 2);
+        appendRow(it);
+
         for (auto screen : screens) {
             auto geo = screen->geometry();
+            auto name = screen->model().isEmpty() ? screen->name() : screen->model();
             auto it = new QStandardItem(i18nc("model - (x,y widthxheight)",
                                               "%1 - (%2,%3 %4×%5)",
-                                              screen->model(),
+                                              name,
                                               QString::number(geo.x()),
                                               QString::number(geo.y()),
                                               QString::number(geo.width()),
@@ -115,6 +123,18 @@ public:
     {
         return item(row)->data(Qt::UserRole).toString();
     }
+
+    Q_SCRIPTABLE int rowForDevice(InputDevice *device)
+    {
+        if (!device) {
+            return 0;
+        } else if (device->isMapToWorkspace()) {
+            return 1;
+        } else {
+            return rowForOutputName(device->outputName());
+        }
+    }
+
     Q_SCRIPTABLE int rowForOutputName(const QString &outputName)
     {
         for (int i = 0, c = rowCount(); i < c; ++i) {
@@ -126,6 +146,11 @@ public:
         // If not found, let's just return the PrimaryOrientation
         return 0;
     }
+
+    Q_SCRIPTABLE bool isMapToWorkspaceAt(int row)
+    {
+        return row == 1;
+    }
 };
 
 /// This model lists the different ways the tablet will fit onto its output
@@ -134,24 +159,58 @@ class OutputsFittingModel : public QStandardItemModel
 public:
     OutputsFittingModel()
     {
-        appendRow(new QStandardItem(i18n("Fit to Output")));
-        appendRow(new QStandardItem(i18n("Fit Output in tablet")));
-        appendRow(new QStandardItem(i18n("Custom size")));
+        appendRow(new QStandardItem(i18n("Fit to Screen")));
+        appendRow(new QStandardItem(i18n("Keep Aspect Ratio and Fit Within Screen")));
+        appendRow(new QStandardItem(i18n("Map to Portion of Screen")));
 
         setItemRoleNames({{Qt::DisplayRole, "display"}});
     }
 };
 
-Tablet::Tablet(QObject *parent, const KPluginMetaData &metaData, const QVariantList &list)
-    : ManagedConfigModule(parent, metaData, list)
+// QMatrix4x4 over DBus is needed for writing calibration matrices
+QDBusArgument &operator<<(QDBusArgument &argument, const QMatrix4x4 &matrix)
+{
+    argument.beginArray(qMetaTypeId<double>());
+    for (quint8 row = 0; row < 4; ++row) {
+        for (quint8 col = 0; col < 4; ++col) {
+            argument << matrix(row, col);
+        }
+    }
+    argument.endArray();
+    return argument;
+}
+
+const QDBusArgument &operator>>(const QDBusArgument &argument, QMatrix4x4 &matrix)
+{
+    argument.beginArray();
+    for (quint8 row = 0; row < 4; ++row) {
+        for (quint8 col = 0; col < 4; ++col) {
+            double val;
+            argument >> val;
+            matrix(row, col) = val;
+        }
+    }
+    argument.endArray();
+    return argument;
+}
+
+Tablet::Tablet(QObject *parent, const KPluginMetaData &metaData)
+    : KQuickManagedConfigModule(parent, metaData)
     , m_toolsModel(new DevicesModel("tabletTool", this))
     , m_padsModel(new DevicesModel("tabletPad", this))
 {
+    qDBusRegisterMetaType<QMatrix4x4>();
+
     qmlRegisterType<OutputsModel>("org.kde.plasma.tablet.kcm", 1, 0, "OutputsModel");
     qmlRegisterType<OrientationsModel>("org.kde.plasma.tablet.kcm", 1, 0, "OrientationsModel");
     qmlRegisterType<OutputsFittingModel>("org.kde.plasma.tablet.kcm", 1, 1, "OutputsFittingModel");
     qmlRegisterType<TabletEvents>("org.kde.plasma.tablet.kcm", 1, 1, "TabletEvents");
     qmlRegisterAnonymousType<InputDevice>("org.kde.plasma.tablet.kcm", 1);
+    qmlRegisterType<CalibrationTool>("org.kde.plasma.tablet.kcm", 1, 1, "CalibrationTool");
+    // This looks weird, but the first type here is the value type. The second type is here is just for the enumerations.
+    // Yes, this IS what they suggest you do: https://doc.qt.io/qt-6/qtqml-cppintegration-definetypes.html#value-types-with-enumerations
+    qmlRegisterType<InputSequence>("org.kde.plasma.tablet.kcm", 1, 1, "inputSequence");
+    qmlRegisterUncreatableMetaObject(InputSequence::staticMetaObject, "org.kde.plasma.tablet.kcm", 1, 1, "InputSequence", "Access to enums & flags only");
 
     connect(m_toolsModel, &DevicesModel::needsSaveChanged, this, &Tablet::refreshNeedsSave);
     connect(m_padsModel, &DevicesModel::needsSaveChanged, this, &Tablet::refreshNeedsSave);
@@ -204,12 +263,12 @@ void Tablet::save()
         for (auto it = m_unsavedMappings[device].cbegin(), itEnd = m_unsavedMappings[device].cend(); it != itEnd; ++it) {
             auto group = generalGroup.group(device).group(it.key());
             for (auto itDevice = it->cbegin(), itDeviceEnd = it->cend(); itDevice != itDeviceEnd; ++itDevice) {
-                const auto key = itDevice->toString(QKeySequence::PortableText);
+                const auto key = itDevice->toConfigFormat();
                 const auto button = QString::number(itDevice.key());
                 if (key.isEmpty()) {
                     group.deleteEntry(button, KConfig::Notify);
                 } else {
-                    group.writeEntry(button, QStringList{"Key", key}, KConfig::Notify);
+                    group.writeEntry(button, key, KConfig::Notify);
                 }
             }
         }
@@ -238,19 +297,19 @@ void Tablet::defaults()
     Q_EMIT settingsRestored();
 }
 
-void Tablet::assignPadButtonMapping(const QString &deviceName, uint button, const QKeySequence &keySequence)
+void Tablet::assignPadButtonMapping(const QString &deviceName, uint button, const InputSequence &keySequence)
 {
     m_unsavedMappings["Tablet"][deviceName][button] = keySequence;
     Q_EMIT settingsRestored();
 }
 
-void Tablet::assignToolButtonMapping(const QString &deviceName, uint button, const QKeySequence &keySequence)
+void Tablet::assignToolButtonMapping(const QString &deviceName, uint button, const InputSequence &keySequence)
 {
     m_unsavedMappings["TabletTool"][deviceName][button] = keySequence;
     Q_EMIT settingsRestored();
 }
 
-QKeySequence Tablet::padButtonMapping(const QString &deviceName, uint button) const
+InputSequence Tablet::padButtonMapping(const QString &deviceName, uint button) const
 {
     if (deviceName.isEmpty()) {
         return {};
@@ -263,13 +322,10 @@ QKeySequence Tablet::padButtonMapping(const QString &deviceName, uint button) co
     const auto cfg = KSharedConfig::openConfig("kcminputrc");
     const auto group = cfg->group("ButtonRebinds").group("Tablet").group(deviceName);
     const auto sequence = group.readEntry(QString::number(button), QStringList());
-    if (sequence.size() != 2) {
-        return {};
-    }
-    return QKeySequence(sequence.constLast());
+    return InputSequence(sequence);
 }
 
-QKeySequence Tablet::toolButtonMapping(const QString &deviceName, uint button) const
+InputSequence Tablet::toolButtonMapping(const QString &deviceName, uint button) const
 {
     if (deviceName.isEmpty()) {
         return {};
@@ -282,10 +338,7 @@ QKeySequence Tablet::toolButtonMapping(const QString &deviceName, uint button) c
     const auto cfg = KSharedConfig::openConfig("kcminputrc");
     const auto group = cfg->group("ButtonRebinds").group("TabletTool").group(deviceName);
     const auto sequence = group.readEntry(QString::number(button), QStringList());
-    if (sequence.size() != 2) {
-        return {};
-    }
-    return QKeySequence(sequence.constLast());
+    return InputSequence(sequence);
 }
 
 DevicesModel *Tablet::toolsModel() const
